/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02691
 |              SERVICES RESEARCH OUTCOMES STUDY, 1995-1996
 |            (DATASET 0002: CLIENT RECORDS ABSTRACTION DATA)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02691-0002-statasetup.do)
 |
 **************************************************************************/

set mem 7m  /* Allocating 7 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Services Research Outcomes Study, 1995-1996, Dataset 0002"

#delimit ;
label define MODE      1 "Hospital Inpatient" 2 "Residential"
                       3 "Outpatient Meth.Maintenance"
                       4 "Outpatient Drug-Free" ;
label define UTYPE     1 "Drug Treatment Unit" 3 "Both Alc/Drug Treatment" ;
label define ENVIRONM  1 "Hospital Inpatient" 2 "Residental Care"
                       3 "Outpatient Care" ;
label define DEAD      0 "Alive at time of follow-up" 1 "Deceased" ;
label define RESP      0 "Non-respondent in follow-up"
                       1 "Respondent in follow-up" ;
label define DISP      71 "Respondents" 73 "Deceased" 86 "Language problem"
                       87 "Incapacitated" 89 "Out of scope" 93 "Unlocatable"
                       94 "Unavailable" 95 "Refused" 96 "Refusal by prison"
                       99 "Final other NIR" ;
label define CLIENTYP  -3 "MISSING" 1 "Hospital In-Patient" 2 "Residential"
                       3 "Out-Patient Detox/Maintenance"
                       4 "Out-Patient Drug-free" 5 "Alcohol only"
                       7 "Combination" 9 "Unknown/Unable to determine" ;
label define Q3_WAIT   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q4_PLAN   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q5_PRIM   -3 "MISSING" -2 "DON'T KNOW" 1 "Self" 2 "Family"
                       3 "Friend/acquaintance" 4 "Clergy" 5 "School"
                       6 "Social service agency"
                       7 "Employee Assistance Program (EAP)"
                       8 "Employer (other than EAP)"
                       9 "Legal system-court order"
                       10 "Legal system-voluntary"
                       11 "Legal system-unspecified" 12 "Private physician"
                       13 "Community mental health center"
                       14 "Other health professional/provider"
                       15 "Another alcohol/drug abuse tx program"
                       16 "Other (SPECIFY)" ;
label define Q6_PRIM   -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED"
                       1 "Public subsidy" 2 "Philanthropy"
                       3 "No payment unspe" 4 "Self-pay"
                       5 "HMO or other pre-paid plan"
                       6 "Private health insurance" 7 "Medicaid" 8 "Medicare"
                       10 "CHAMPUS" 11 "VA" 12 "Social services"
                       14 "Other (SPECIFY)" ;
label define Q7_SECN   -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED"
                       1 "Public subsidy" 2 "Philanthropy"
                       3 "No payment unspe" 4 "Self-pay"
                       5 "HMO or other pre-paid plan"
                       6 "Private health insurance" 7 "Medicaid" 8 "Medicare"
                       9 "DOD" 10 "CHAMPUS" 11 "VA" 12 "Social services"
                       13 "Public housing/home relief" 14 "Other (SPECIFY)" ;
label define Q10_AGE   -3 "MISSING" -2 "DON'T KNOW" 57 "57-64" 65 "65-74"
                       75 "75+" ;
label define Q11GEND   -3 "MISSING" -2 "DON'T KNOW" 1 "Male" 2 "Female" ;
label define Q12RACE   -3 "MISSING" -2 "DON'T KNOW"
                       2 "American Indian or Alaskan Native"
                       3 "Asian or Pacific Islander"
                       4 "Black (Afro-American)" 5 "White"
                       6 "Other (SPECIFY)" ;
label define Q13ETHN   -3 "MISSING" -2 "DON'T KNOW" 1 "Hispanic"
                       2 "Not of Hispanic origin" ;
label define Q14MSTA   -3 "MISSING" -2 "DON'T KNOW" 1 "Never married"
                       2 "Married/common law" 3 "Widowed"
                       4 "Separated/divorced" 5 "Single" 6 "Other (SPECIFY)" ;
label define Q15CHLD   -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q16CHLV   -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q17ARNG   -3 "MISSING" -2 "DON'T KNOW"
                       1 "No stable arrange. (include homeless, sh"
                       2 "With partner/spouse" 3 "With parent(s)"
                       4 "With other family" 5 "With unrelated other(s)"
                       6 "With children but no other adult" 7 "Alone"
                       8 "Controlled environment" 9 "Other (SPECIFY)" ;
label define Q18EDU    -3 "MISSING" -2 "DON'T KNOW" 1 "Less than 8 years"
                       2 "8-11 Years" 3 "Less than high school grad., NOS"
                       4 "High school graduate/GED" 5 "Some college"
                       6 "College graduate" 7 "Postgraduate"
                       8 "Other (SPECIFY)" ;
label define Q19STU    -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q20EMPL   -3 "MISSING" -2 "DON'T KNOW"
                       1 "Full-time (35 hrs/wk or more)"
                       2 "Part-time (less than 35 hrs/wk)" 3 "Employed, NOS"
                       4 "Keeping house, not otherwise employed"
                       5 "Unemployed, retired" 6 "Unemployed, disabled"
                       7 "Unemployed, NOS" 8 "Other (SPECIFY)" ;
label define Q22DWI    -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q23OTHR   -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q24JAIL   -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q25TRTMN  -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define Q26HOSP   -3 "MISSING" -2 "DON'T KNOW" ;
label define Q27MED    -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q28HIST   -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q29ABUSE  -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q30PREG   -3 "MISSING" -2 "DON'T KNOW"
                       1 "NOT APPLICABLE, client is male" 2 "Not pregnant"
                       3 "Pregnant" ;
label define Q31PROB   -3 "MISSING" -2 "DON'T KNOW"
                       1 "Single drug abuse only (exclud. alcohol)"
                       2 "Polydrug abuse only (excluding alcohol)"
                       3 "Alcohol abuse only"
                       4 "Alcohol & abuse of one other drug combi"
                       5 "Alcohol & abuse of 2 or more other drug"
                       6 "Other (SPECIFY)" ;
label define Q32PRIN   -3 "MISSING" -2 "DON'T KNOW"
                       1 "Single drug abuse only (exclud. alcohol)"
                       2 "Polydrug abuse only (excluding alcohol)"
                       3 "Alcohol abuse only"
                       4 "Alcohol and other drug abuse combined"
                       5 "Other (SPECIFY)" ;
label define Q34HIV    -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Negative"
                       2 "Positive" 3 "Suspected" 4 "Other (SPECIFY)" ;
label define Q34AINF   -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q35A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q35B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q35C      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q36A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q36B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q36C      -3 "MISSING" -2 "DON'T KNOW" ;
label define Q37A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q37B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q37C      -3 "MISSING" -2 "DON'T KNOW" ;
label define Q38A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q38B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q38C      -3 "MISSING" -2 "DON'T KNOW" ;
label define Q39A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q39B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q39C      -3 "MISSING" -2 "DON'T KNOW" ;
label define Q40A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q40B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q40C      -3 "MISSING" -2 "DON'T KNOW" ;
label define Q41A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q41B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q41C      -3 "MISSING" -2 "DON'T KNOW" ;
label define Q42A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q42B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q42C      -3 "MISSING" -2 "DON'T KNOW" ;
label define Q43A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q43B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q43C      -3 "MISSING" -2 "DON'T KNOW" ;
label define Q44A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q44B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q44C      -3 "MISSING" -2 "DON'T KNOW" ;
label define Q45A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q45B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q45C      -3 "MISSING" -2 "DON'T KNOW" ;
label define Q46A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q46B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q46C      -3 "MISSING" -2 "DON'T KNOW" ;
label define Q47A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q47B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q47C      -3 "MISSING" -2 "DON'T KNOW" ;
label define Q48A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q48B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q48C      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q49A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q49B      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q49C      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q50A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q50B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q50C      -3 "MISSING" -2 "DON'T KNOW" ;
label define Q51A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q51B      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q51C      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q52DRUG   -3 "MISSING" -2 "DON'T KNOW" 1 "No drug of choice"
                       35 "Cocaine" 36 "Crack" 37 "Heroin"
                       38 "Non-treatment methadone"
                       39 "Other opiates/synthetics" 40 "Barbiturates"
                       41 "Benzodiazepines" 42 "Other sedatives/hypnotics"
                       43 "Methamphetamines" 44 "Other amphetamines"
                       45 "Marijuana/hashish/THC" 46 "PCP/LSD" 48 "Inhalants"
                       49 "Over the counter (SPECIFY)" 50 "Alcohol"
                       51 "Other (SPECIFY)" ;
label define Q53INT    -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q53ADUSE  -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q53BFRE   -3 "MISSING" -2 "DON'T KNOW" 1 "Daily"
                       2 "Regularly but not daily" 3 "Sporadically" ;
label define Q54NUM    -3 "MISSING" -2 "DON'T KNOW" 15 "15+" ;
label define Q55POSTV  -3 "MISSING" -2 "DON'T KNOW" 15 "15+" ;
label define Q56TEST   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q56_T1    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Urine" 2 "Serum/Blood" 3 "Other (SPECIFY)" ;
label define Q56_T2    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Urine" 2 "Serum/Blood" 3 "Other (SPECIFY)" ;
label define Q56_MON1  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q56_DAY1  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q56_YR1   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q56_MON2  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q56_DAY2  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q56_YR2   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q56A1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56A2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56B1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56B2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56C1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56C2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56D1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56D2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56E1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56E2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56F1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56F2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56G1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56G2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56H1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56H2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56I1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56I2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56J1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56J2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56K1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56K2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56L1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       2 "Test negative/not applicable" ;
label define Q56L2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       2 "Test negative/not applicable" ;
label define Q56M1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56M2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56N1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56N2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56O1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q56O2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Test positive" 2 "Test negative/not applicable" ;
label define Q57TOTN   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       11 "11+" ;
label define Q57AYRN   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q58PAST   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q58_PRA   -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED"
                       1 "Cocaine (excluding crack)" 2 "Crack" 3 "Heroin"
                       4 "Non-treatment methadone"
                       5 "Other opiates/synthetics" 7 "Benzodiazepines"
                       8 "Other sedatives/hypnotics" 9 "Methamphetamines"
                       11 "Marijuana/Hashish/TCP" 12 "PCP/LSD" 14 "Inhalants"
                       15 "Alcohol" 16 "Polydrug (excluding alcohol)"
                       17 "Combination alcohol and other drug"
                       18 "Sub. abuse/mental ill. (dual diag.)"
                       97 "Other (SPECIFY IN COMMENTS)" ;
label define Q58_SECA  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Cocaine (excluding crack)" 2 "Crack" 3 "Heroin"
                       4 "Non-treatment methadone"
                       5 "Other opiates/synthetics" 6 "Barbiturates"
                       7 "Benzodiazepines" 8 "Other sedatives/hypnotics"
                       9 "Methamphetamines" 10 "Other amphetamines"
                       11 "Marijuana/Hashish/TCP" 12 "PCP/LSD" 14 "Inhalants"
                       15 "Alcohol" 16 "Polydrug (excluding alcohol)"
                       17 "Combination alcohol and other drug"
                       18 "Sub. abuse/mental ill. (dual diag.)"
                       19 "No secondary drug use"
                       97 "Other (SPECIFY IN COMMENTS)" ;
label define Q58_FAA   -3 "MISSING" -2 "DON'T KNOW" 1 "Here" 2 "Elsewhere" ;
label define Q58_REA   -3 "MISSING" -2 "DON'T KNOW"
                       1 "Completed planned treatment services"
                       2 "Not complete tx, referred elsewhere"
                       3 "Not complete tx, administration choice"
                       4 "Not complete tx, participant choice"
                       5 "Not complete tx, choice not mentioned"
                       6 "Incarcerated" 7 "Other (SPECIFY IN COMMENTS)" ;
label define Q58_PRB   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Cocaine (excluding crack)" 2 "Crack"
                       3 "Heroin" 5 "Other opiates/synthetics"
                       7 "Benzodiazepines" 9 "Methamphetamines"
                       11 "Marijuana/Hashish/TCP" 15 "Alcohol"
                       16 "Polydrug (excluding alcohol)"
                       17 "Combination alcohol and other drug"
                       18 "Sub. abuse/mental ill. (dual diag.)"
                       97 "Other (SPECIFY IN COMMENTS)" ;
label define Q58_SECB  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Cocaine (excluding crack)" 2 "Crack" 3 "Heroin"
                       4 "Non-treatment methadone" 7 "Benzodiazepines"
                       11 "Marijuana/Hashish/TCP" 15 "Alcohol"
                       16 "Polydrug (excluding alcohol)"
                       17 "Combination alcohol and other drug"
                       18 "Sub. abuse/mental ill. (dual diag.)"
                       19 "No secondary drug use"
                       97 "Other (SPECIFY IN COMMENTS)" ;
label define Q58_FAB   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Here" 2 "Elsewhere" ;
label define Q58_REB   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Completed planned treatment services"
                       2 "Not complete tx, referred elsewhere"
                       3 "Not complete tx, administration choice"
                       4 "Not complete tx, participant choice"
                       5 "Not complete tx, choice not mentioned"
                       6 "Incarcerated" 7 "Other (SPECIFY IN COMMENTS)" ;
label define Q58_PRC   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Cocaine (excluding crack)" 2 "Crack" 3 "Heroin"
                       5 "Other opiates/synthetics" 9 "Methamphetamines"
                       11 "Marijuana/Hashish/TCP" 15 "Alcohol"
                       16 "Polydrug (excluding alcohol)"
                       17 "Combination alcohol and other drug"
                       18 "Sub. abuse/mental ill. (dual diag.)"
                       97 "Other (SPECIFY IN COMMENTS)" ;
label define Q58_SECC  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Cocaine (excluding crack)" 7 "Benzodiazepines"
                       11 "Marijuana/Hashish/TCP" 15 "Alcohol"
                       16 "Polydrug (excluding alcohol)"
                       17 "Combination alcohol and other drug"
                       18 "Sub. abuse/mental ill. (dual diag.)"
                       19 "No secondary drug use"
                       97 "Other (SPECIFY IN COMMENTS)" ;
label define Q58_FAC   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Here" 2 "Elsewhere" ;
label define Q58_REC   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Completed planned treatment services"
                       2 "Not complete tx, referred elsewhere"
                       3 "Not complete tx, administration choice"
                       4 "Not complete tx, participant choice" ;
label define Q58_PRD   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Cocaine (excluding crack)" 3 "Heroin" 15 "Alcohol"
                       17 "Combination alcohol and other drug"
                       18 "Sub. abuse/mental ill. (dual diag.)" ;
label define Q58_SECD  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       11 "Marijuana/Hashish/TCP"
                       16 "Polydrug (excluding alcohol)"
                       17 "Combination alcohol and other drug"
                       19 "No secondary drug use"
                       97 "Other (SPECIFY IN COMMENTS)" ;
label define Q58_FAD   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Here" 2 "Elsewhere" ;
label define Q58_RED   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Completed planned treatment services"
                       2 "Not complete tx, referred elsewhere" ;
label define Q58_PRE   -3 "MISSING" -2 "DON'T KNOW"
                       1 "Cocaine (excluding crack)" ;
label define Q58_SECE  -3 "MISSING" -2 "DON'T KNOW" 15 "Alcohol" ;
label define Q58_FAE   -3 "MISSING" 1 "Here" 2 "Elsewhere" ;
label define Q58_REE   -3 "MISSING" -2 "DON'T KNOW"
                       1 "Completed planned treatment services" ;
label define Q58_PRF   -3 "MISSING" -2 "DON'T KNOW" ;
label define Q58_SECF  -3 "MISSING" -2 "DON'T KNOW" ;
label define Q58_FAF   -3 "MISSING" 2 "Elsewhere" ;
label define Q58_REF   -3 "MISSING" -2 "DON'T KNOW"
                       1 "Completed planned treatment services" ;
label define Q58_PRG   -3 "MISSING" -2 "DON'T KNOW" ;
label define Q58_SECG  -3 "MISSING" -2 "DON'T KNOW" ;
label define Q58_FAG   -3 "MISSING" 2 "Elsewhere" ;
label define Q58_REG   -3 "MISSING" -2 "DON'T KNOW" ;
label define Q58_PRH   -3 "MISSING" -2 "DON'T KNOW" ;
label define Q58_SECH  -3 "MISSING" -2 "DON'T KNOW" ;
label define Q58_FAH   -3 "MISSING" 2 "Elsewhere" ;
label define Q58_REH   -3 "MISSING" -2 "DON'T KNOW" ;
label define Q58_PRI   -3 "MISSING" -2 "DON'T KNOW" ;
label define Q58_SECI  -3 "MISSING" -2 "DON'T KNOW" ;
label define Q58_FAI   -3 "MISSING" 2 "Elsewhere" ;
label define Q58_REI   -3 "MISSING" -2 "DON'T KNOW" ;
label define Q58_PRJ   -3 "MISSING" ;
label define Q58_SECJ  -3 "MISSING" ;
label define Q58_FAJ   -3 "MISSING" ;
label define Q58_REJ   -3 "MISSING" ;
label define Q59_SER   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Not given" 2 "Actually given, completed"
                       3 "Actually given, not completed by admin."
                       4 "Not completed client choice"
                       5 "Not completed no mention of choice"
                       6 "Planned or recom., can't confirm if act." ;
label define Q59_FAC   -3 "MISSING" -2 "DON'T KNOW" 1 "Here" 2 "Elsewhere" ;
label define Q59_NO    -3 "MISSING" -2 "DON'T KNOW" 50 "50+" ;
label define Q60_SER   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Not given" 2 "Actually given, completed"
                       3 "Actually given, not completed by admin."
                       4 "Not completed client choice"
                       5 "Not completed no mention of choice"
                       6 "Planned or recom., can't confirm if act." ;
label define Q60_FAC   -3 "MISSING" -2 "DON'T KNOW" 1 "Here" 2 "Elsewhere" ;
label define Q60_NO    -3 "MISSING" -2 "DON'T KNOW" 50 "50+" ;
label define Q61_SER   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Not given" 2 "Actually given, completed"
                       3 "Actually given, not completed by admin."
                       4 "Not completed client choice"
                       5 "Not completed no mention of choice"
                       6 "Planned or recom., can't confirm if act." ;
label define Q61_FAC   -3 "MISSING" -2 "DON'T KNOW" 1 "Here" 2 "Elsewhere" ;
label define Q61_NO    -3 "MISSING" -2 "DON'T KNOW" 50 "50+" ;
label define Q62_SER   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Not given" 2 "Actually given, completed"
                       3 "Actually given, not completed by admin."
                       4 "Not completed client choice"
                       5 "Not completed no mention of choice"
                       6 "Planned or recom., can't confirm if act." ;
label define Q62_FAC   -3 "MISSING" -2 "DON'T KNOW" 1 "Here" 2 "Elsewhere" ;
label define Q62_NO    -3 "MISSING" -2 "DON'T KNOW" 50 "50+" ;
label define Q63_SER   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Not given" 2 "Actually given, completed"
                       3 "Actually given, not completed by admin."
                       4 "Not completed client choice"
                       6 "Planned or recom., can't confirm if act." ;
label define Q63_FAC   -3 "MISSING" -2 "DON'T KNOW" 1 "Here" 2 "Elsewhere" ;
label define Q64_SER   -3 "MISSING" -2 "DON'T KNOW" 1 "Not given"
                       2 "Actually given, completed"
                       3 "Actually given, not completed by admin."
                       4 "Not completed client choice"
                       6 "Planned or recom., can't confirm if act." ;
label define Q64_FAC   -3 "MISSING" -2 "DON'T KNOW" 1 "Here" 2 "Elsewhere" ;
label define Q65_SER   -3 "MISSING" -2 "DON'T KNOW" 1 "Not given"
                       2 "Actually given, completed"
                       3 "Actually given, not completed by admin."
                       4 "Not completed client choice"
                       5 "Not completed no mention of choice"
                       6 "Planned or recom., can't confirm if act." ;
label define Q65_FAC   -3 "MISSING" -2 "DON'T KNOW" 1 "Here" 2 "Elsewhere" ;
label define Q66_SER   -3 "MISSING" -2 "DON'T KNOW" 1 "Not given"
                       2 "Actually given, completed"
                       3 "Actually given, not completed by admin."
                       4 "Not completed client choice"
                       5 "Not completed no mention of choice"
                       6 "Planned or recom., can't confirm if act." ;
label define Q66_FAC   -3 "MISSING" -2 "DON'T KNOW" 1 "Here" 2 "Elsewhere" ;
label define Q67_SER   -3 "MISSING" -2 "DON'T KNOW" 1 "Not given"
                       2 "Actually given, completed"
                       3 "Actually given, not completed by admin."
                       4 "Not completed client choice"
                       5 "Not completed no mention of choice"
                       6 "Planned or recom., can't confirm if act." ;
label define Q67_FAC   -3 "MISSING" -2 "DON'T KNOW" 1 "Here" 2 "Elsewhere" ;
label define Q68_SER   -3 "MISSING" -2 "DON'T KNOW" 1 "Not given"
                       2 "Actually given, completed"
                       3 "Actually given, not completed by admin."
                       4 "Not completed client choice"
                       5 "Not completed no mention of choice"
                       6 "Planned or recom., can't confirm if act." ;
label define Q68_FAC   -3 "MISSING" -2 "DON'T KNOW" 1 "Here" 2 "Elsewhere" ;
label define Q69_SER   -3 "MISSING" -2 "DON'T KNOW" 1 "Not given"
                       2 "Actually given, completed"
                       6 "Planned or recom., can't confirm if act." ;
label define Q69_FAC   -3 "MISSING" -2 "DON'T KNOW" 1 "Here" 2 "Elsewhere" ;
label define Q70MED    -3 "MISSING" 0 "No" 1 "Yes" ;
label define Q71ADM    -3 "MISSING" 0 "No" 1 "Yes" ;
label define Q72DIS    -3 "MISSING" 0 "No" 1 "Yes" ;
label define Q73OTHR   -3 "MISSING" 0 "No" 1 "Yes" ;
label define Q74_METH  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define Q74ATOT   -3 "MISSING" -2 "DON'T KNOW" ;
label define Q74AGIV   -3 "MISSING" -2 "DON'T KNOW" ;
label define Q74ANUM   -3 "MISSING" -2 "DON'T KNOW" ;
label define Q74APLC   -3 "MISSING" -2 "DON'T KNOW" 1 "Here" 2 "At home" ;
label define Q74BTOT   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q74BGIV   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q74BNUM   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q74BPLC   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Here" 2 "At home" 3 "Here/At Home" ;
label define Q75_HOME  -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q76_DIS   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Participant deceased"
                       2 "Completed planned treatment"
                       3 "Not complete, referred elsewhere"
                       4 "Not complete, administration choice"
                       5 "Not complete, participant choice"
                       6 "Not complete, choice not mentioned"
                       7 "Incarcerated" 8 "Other (SPECIFY REASON IN B)" ;
label define Q79SUB    -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q80_PLN   -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q81AFTR   -3 "MISSING" -2 "DON'T KNOW" 1 "Services specified" ;
label define Q74A_YR   -3 "MISSING" -2 "DON'T KNOW" ;
label define Q74B_YR   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW" ;
label define Q77_YR    -3 "MISSING" ;
label define Q78_YR    -3 "MISSING" -2 "DON'T KNOW" ;
label define Q81A      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q81B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q81C      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q81D      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q81E      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q81F      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q81G      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q81H      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q81I      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q81J      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q82AFTR   -3 "MISSING" -2 "DON'T KNOW" 1 "No treatment"
                       2 "Hospital inpatient" 3 "Residential"
                       4 "Outpatient/methadone maintenance"
                       5 "Other outpatient" 6 "Other (SPECIFY)" ;
label define Q83BILL   -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" 3 "Other (SPECIFY)" ;
label define Q83A_DOL  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 0 "None" 1 "$1-99" 2 "$100-499"
                       3 "$500-999" 4 "$1,000-4,999" 5 "$5,000-9,999"
                       6 "$10,000-14,999" 7 "$15,000-40,000" ;
label define Q83CODE   -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED"
                       1 "Full amount billed" 2 "Sliding fee amount"
                       3 "Reduced amount: |___|___|% of full bill"
                       4 "Other (SPECIFY)" ;
label define Q83PCNT   -3 "MISSING" -2 "DON'T KNOW" ;
label define Q83B      -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q353CMNT  -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define Q33B1RCD  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 0 "NO DIAGNOSIS (000.00)"
                       1 "ALC IND DISORD (291.00-291.99)"
                       2 "SUBST IND DISORD (292.00-292.99)"
                       3 "ALC INTOXICATION (303.00-303.89)"
                       4 "ALC DEPEND (303.90-303.99)"
                       5 "OPIOID DEPEND (304.00-304.09)"
                       6 "COCAINE DEPEND (304.20-304.29)"
                       7 "CANNABIS DEPEND (304.30-304.39)"
                       8 "OTH SUBST DEPEND (304.10-304.19,304.40-3"
                       9 "ALC ABUSE (305.00-305.09)"
                       10 "CANNABIS ABUSE (305.20-305.29)"
                       11 "OTH SUBST ABUSE (305.30-305.49, 305.70-3"
                       12 "OPIOID ABUSE (305.50-305.59)"
                       13 "COCAINE ABUSE (305.60-305.69)"
                       14 "MENTAL HEALTH CONDITION" 15 "OTHER CONDITION" ;
label define Q33B2RCD  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 0 "NO DIAGNOSIS (000.00)"
                       1 "ALC IND DISORD (291.00-291.99)"
                       2 "SUBST IND DISORD (292.00-292.99)"
                       3 "ALC INTOXICATION (303.00-303.89)"
                       4 "ALC DEPEND (303.90-303.99)"
                       5 "OPIOID DEPEND (304.00-304.09)"
                       6 "COCAINE DEPEND (304.20-304.29)"
                       7 "CANNABIS DEPEND (304.30-304.39)"
                       8 "OTH SUBST DEPEND (304.10-304.19,304.40-3"
                       9 "ALC ABUSE (305.00-305.09)"
                       10 "CANNABIS ABUSE (305.20-305.29)"
                       11 "OTH SUBST ABUSE (305.30-305.49, 305.70-3"
                       12 "OPIOID ABUSE (305.50-305.59)"
                       13 "COCAINE ABUSE (305.60-305.69)"
                       14 "MENTAL HEALTH CONDITION" 15 "OTHER CONDITION" ;
label define Q33CODE   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 0 "NO DIAGNOSIS (000.00)"
                       1 "ALC IND DISORD (291.00-291.99)"
                       2 "SUBST IND DISORD (292.00-292.99)"
                       3 "ALC INTOXICATION (303.00-303.89)"
                       4 "ALC DEPEND (303.90-303.99)"
                       5 "OPIOID DEPEND (304.00-304.09)"
                       6 "COCAINE DEPEND (304.20-304.29)"
                       7 "CANNABIS DEPEND (304.30-304.39)"
                       8 "OTH SUBST DEPEND (304.10-304.19,304.40-3"
                       9 "ALC ABUSE (305.00-305.09)"
                       10 "CANNABIS ABUSE (305.20-305.29)"
                       11 "OTH SUBST ABUSE (305.30-305.49, 305.70-3"
                       12 "OPIOID ABUSE (305.50-305.59)"
                       13 "COCAINE ABUSE (305.60-305.69)"
                       14 "MENTAL HEALTH CONDITION" 15 "OTHER CONDITION" ;
label define Q33RCODE  -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 0 "NO DIAGNOSIS (000.00)"
                       1 "ALC IND DISORD (291.00-291.99)"
                       2 "SUBST IND DISORD (292.00-292.99)"
                       3 "ALC INTOXICATION (303.00-303.89)"
                       4 "ALC DEPEND (303.90-303.99)"
                       5 "OPIOID DEPEND (304.00-304.09)"
                       6 "COCAINE DEPEND (304.20-304.29)"
                       7 "CANNABIS DEPEND (304.30-304.39)"
                       8 "OTH SUBST DEPEND (304.10-304.19,304.40-3"
                       9 "ALC ABUSE (305.00-305.09)"
                       10 "CANNABIS ABUSE (305.20-305.29)"
                       11 "OTH SUBST ABUSE (305.30-305.49, 305.70-3"
                       12 "OPIOID ABUSE (305.50-305.59)"
                       13 "COCAINE ABUSE (305.60-305.69)"
                       14 "MENTAL HEALTH CONDITION" 15 "OTHER CONDITION" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CLIENTID = . if (CLIENTID <= -1 )
replace FAC_ID = . if (FAC_ID <= -1 )
replace MODE = . if (MODE <= -1 )
replace UTYPE = . if (UTYPE <= -1 )
replace ENVIRONM = . if (ENVIRONM <= -1 )
replace DEAD = . if (DEAD <= -1 )
replace RESP = . if (RESP <= -1 )
replace CLIENTYP = . if (CLIENTYP <= -1 )
replace Q3_WAIT = . if (Q3_WAIT <= -1 )
replace Q4_PLAN = . if (Q4_PLAN <= -1 )
replace Q5_PRIM = . if (Q5_PRIM <= -1 )
replace Q6_PRIM = . if (Q6_PRIM <= -1 )
replace Q7_SECN = . if (Q7_SECN <= -1 )
replace Q10_AGE = . if (Q10_AGE <= -1 )
replace Q11GEND = . if (Q11GEND <= -1 )
replace Q12RACE = . if (Q12RACE <= -1 )
replace Q13ETHN = . if (Q13ETHN <= -1 )
replace Q14MSTA = . if (Q14MSTA <= -1 )
replace Q15CHLD = . if (Q15CHLD <= -1 )
replace Q16CHLV = . if (Q16CHLV <= -1 )
replace Q17ARNG = . if (Q17ARNG <= -1 )
replace Q18EDU = . if (Q18EDU <= -1 )
replace Q19STU = . if (Q19STU <= -1 )
replace Q20EMPL = . if (Q20EMPL <= -1 )
replace Q22DWI = . if (Q22DWI <= -1 )
replace Q23OTHR = . if (Q23OTHR <= -1 )
replace Q24JAIL = . if (Q24JAIL <= -1 )
replace Q25TRTMN = . if (Q25TRTMN <= -1 )
replace Q26HOSP = . if (Q26HOSP <= -1 )
replace Q27MED = . if (Q27MED <= -1 )
replace Q28HIST = . if (Q28HIST <= -1 )
replace Q29ABUSE = . if (Q29ABUSE <= -1 )
replace Q30PREG = . if (Q30PREG <= -1 )
replace Q31PROB = . if (Q31PROB <= -1 )
replace Q32PRIN = . if (Q32PRIN <= -1 )
replace Q34HIV = . if (Q34HIV <= -1 )
replace Q34AINF = . if (Q34AINF <= -1 )
replace Q35A = . if (Q35A <= -1 )
replace Q35B = . if (Q35B <= -1 )
replace Q35C = . if (Q35C <= -1 )
replace Q36A = . if (Q36A <= -1 )
replace Q36B = . if (Q36B <= -1 )
replace Q36C = . if (Q36C <= -1 )
replace Q37A = . if (Q37A <= -1 )
replace Q37B = . if (Q37B <= -1 )
replace Q37C = . if (Q37C <= -1 )
replace Q38A = . if (Q38A <= -1 )
replace Q38B = . if (Q38B <= -1 )
replace Q38C = . if (Q38C <= -1 )
replace Q39A = . if (Q39A <= -1 )
replace Q39B = . if (Q39B <= -1 )
replace Q39C = . if (Q39C <= -1 )
replace Q40A = . if (Q40A <= -1 )
replace Q40B = . if (Q40B <= -1 )
replace Q40C = . if (Q40C <= -1 )
replace Q41A = . if (Q41A <= -1 )
replace Q41B = . if (Q41B <= -1 )
replace Q41C = . if (Q41C <= -1 )
replace Q42A = . if (Q42A <= -1 )
replace Q42B = . if (Q42B <= -1 )
replace Q42C = . if (Q42C <= -1 )
replace Q43A = . if (Q43A <= -1 )
replace Q43B = . if (Q43B <= -1 )
replace Q43C = . if (Q43C <= -1 )
replace Q44A = . if (Q44A <= -1 )
replace Q44B = . if (Q44B <= -1 )
replace Q44C = . if (Q44C <= -1 )
replace Q45A = . if (Q45A <= -1 )
replace Q45B = . if (Q45B <= -1 )
replace Q45C = . if (Q45C <= -1 )
replace Q46A = . if (Q46A <= -1 )
replace Q46B = . if (Q46B <= -1 )
replace Q46C = . if (Q46C <= -1 )
replace Q47A = . if (Q47A <= -1 )
replace Q47B = . if (Q47B <= -1 )
replace Q47C = . if (Q47C <= -1 )
replace Q48A = . if (Q48A <= -1 )
replace Q48B = . if (Q48B <= -1 )
replace Q48C = . if (Q48C <= -1 )
replace Q49A = . if (Q49A <= -1 )
replace Q49B = . if (Q49B <= -1 )
replace Q49C = . if (Q49C <= -1 )
replace Q50A = . if (Q50A <= -1 )
replace Q50B = . if (Q50B <= -1 )
replace Q50C = . if (Q50C <= -1 )
replace Q51A = . if (Q51A <= -1 )
replace Q51B = . if (Q51B <= -1 )
replace Q51C = . if (Q51C <= -1 )
replace Q52DRUG = . if (Q52DRUG <= -1 )
replace Q53INT = . if (Q53INT <= -1 )
replace Q53ADUSE = . if (Q53ADUSE <= -1 )
replace Q53BFRE = . if (Q53BFRE <= -1 )
replace Q54NUM = . if (Q54NUM <= -1 )
replace Q55POSTV = . if (Q55POSTV <= -1 )
replace Q56TEST = . if (Q56TEST <= -1 )
replace Q56_T1 = . if (Q56_T1 <= -1 )
replace Q56_T2 = . if (Q56_T2 <= -1 )
replace Q56_MON1 = . if (Q56_MON1 <= -1 )
replace Q56_DAY1 = . if (Q56_DAY1 <= -1 )
replace Q56_YR1 = . if (Q56_YR1 <= -1 )
replace Q56_MON2 = . if (Q56_MON2 <= -1 )
replace Q56_DAY2 = . if (Q56_DAY2 <= -1 )
replace Q56_YR2 = . if (Q56_YR2 <= -1 )
replace Q56A1 = . if (Q56A1 <= -1 )
replace Q56A2 = . if (Q56A2 <= -1 )
replace Q56B1 = . if (Q56B1 <= -1 )
replace Q56B2 = . if (Q56B2 <= -1 )
replace Q56C1 = . if (Q56C1 <= -1 )
replace Q56C2 = . if (Q56C2 <= -1 )
replace Q56D1 = . if (Q56D1 <= -1 )
replace Q56D2 = . if (Q56D2 <= -1 )
replace Q56E1 = . if (Q56E1 <= -1 )
replace Q56E2 = . if (Q56E2 <= -1 )
replace Q56F1 = . if (Q56F1 <= -1 )
replace Q56F2 = . if (Q56F2 <= -1 )
replace Q56G1 = . if (Q56G1 <= -1 )
replace Q56G2 = . if (Q56G2 <= -1 )
replace Q56H1 = . if (Q56H1 <= -1 )
replace Q56H2 = . if (Q56H2 <= -1 )
replace Q56I1 = . if (Q56I1 <= -1 )
replace Q56I2 = . if (Q56I2 <= -1 )
replace Q56J1 = . if (Q56J1 <= -1 )
replace Q56J2 = . if (Q56J2 <= -1 )
replace Q56K1 = . if (Q56K1 <= -1 )
replace Q56K2 = . if (Q56K2 <= -1 )
replace Q56L1 = . if (Q56L1 <= -1 )
replace Q56L2 = . if (Q56L2 <= -1 )
replace Q56M1 = . if (Q56M1 <= -1 )
replace Q56M2 = . if (Q56M2 <= -1 )
replace Q56N1 = . if (Q56N1 <= -1 )
replace Q56N2 = . if (Q56N2 <= -1 )
replace Q56O1 = . if (Q56O1 <= -1 )
replace Q56O2 = . if (Q56O2 <= -1 )
replace Q57TOTN = . if (Q57TOTN <= -1 )
replace Q57AYRN = . if (Q57AYRN <= -1 )
replace Q58PAST = . if (Q58PAST <= -1 )
replace Q58_PRA = . if (Q58_PRA <= -1 )
replace Q58_SECA = . if (Q58_SECA <= -1 )
replace Q58_FAA = . if (Q58_FAA <= -1 )
replace Q58_REA = . if (Q58_REA <= -1 )
replace Q58_PRB = . if (Q58_PRB <= -1 )
replace Q58_SECB = . if (Q58_SECB <= -1 )
replace Q58_FAB = . if (Q58_FAB <= -1 )
replace Q58_REB = . if (Q58_REB <= -1 )
replace Q58_PRC = . if (Q58_PRC <= -1 )
replace Q58_SECC = . if (Q58_SECC <= -1 )
replace Q58_FAC = . if (Q58_FAC <= -1 )
replace Q58_REC = . if (Q58_REC <= -1 )
replace Q58_PRD = . if (Q58_PRD <= -1 )
replace Q58_SECD = . if (Q58_SECD <= -1 )
replace Q58_FAD = . if (Q58_FAD <= -1 )
replace Q58_RED = . if (Q58_RED <= -1 )
replace Q58_PRE = . if (Q58_PRE <= -1 )
replace Q58_SECE = . if (Q58_SECE <= -1 )
replace Q58_FAE = . if (Q58_FAE <= -1 )
replace Q58_REE = . if (Q58_REE <= -1 )
replace Q58_PRF = . if (Q58_PRF <= -1 )
replace Q58_SECF = . if (Q58_SECF <= -1 )
replace Q58_FAF = . if (Q58_FAF <= -1 )
replace Q58_REF = . if (Q58_REF <= -1 )
replace Q58_PRG = . if (Q58_PRG <= -1 )
replace Q58_SECG = . if (Q58_SECG <= -1 )
replace Q58_FAG = . if (Q58_FAG <= -1 )
replace Q58_REG = . if (Q58_REG <= -1 )
replace Q58_PRH = . if (Q58_PRH <= -1 )
replace Q58_SECH = . if (Q58_SECH <= -1 )
replace Q58_FAH = . if (Q58_FAH <= -1 )
replace Q58_REH = . if (Q58_REH <= -1 )
replace Q58_PRI = . if (Q58_PRI <= -1 )
replace Q58_SECI = . if (Q58_SECI <= -1 )
replace Q58_FAI = . if (Q58_FAI <= -1 )
replace Q58_REI = . if (Q58_REI <= -1 )
replace Q58_PRJ = . if (Q58_PRJ <= -1 )
replace Q58_SECJ = . if (Q58_SECJ <= -1 )
replace Q58_FAJ = . if (Q58_FAJ <= -1 )
replace Q58_REJ = . if (Q58_REJ <= -1 )
replace Q59_SER = . if (Q59_SER <= -1 )
replace Q59_FAC = . if (Q59_FAC <= -1 )
replace Q59_NO = . if (Q59_NO <= -1 )
replace Q60_SER = . if (Q60_SER <= -1 )
replace Q60_FAC = . if (Q60_FAC <= -1 )
replace Q60_NO = . if (Q60_NO <= -1 )
replace Q61_SER = . if (Q61_SER <= -1 )
replace Q61_FAC = . if (Q61_FAC <= -1 )
replace Q61_NO = . if (Q61_NO <= -1 )
replace Q62_SER = . if (Q62_SER <= -1 )
replace Q62_FAC = . if (Q62_FAC <= -1 )
replace Q62_NO = . if (Q62_NO <= -1 )
replace Q63_SER = . if (Q63_SER <= -1 )
replace Q63_FAC = . if (Q63_FAC <= -1 )
replace Q64_SER = . if (Q64_SER <= -1 )
replace Q64_FAC = . if (Q64_FAC <= -1 )
replace Q65_SER = . if (Q65_SER <= -1 )
replace Q65_FAC = . if (Q65_FAC <= -1 )
replace Q66_SER = . if (Q66_SER <= -1 )
replace Q66_FAC = . if (Q66_FAC <= -1 )
replace Q67_SER = . if (Q67_SER <= -1 )
replace Q67_FAC = . if (Q67_FAC <= -1 )
replace Q68_SER = . if (Q68_SER <= -1 )
replace Q68_FAC = . if (Q68_FAC <= -1 )
replace Q69_SER = . if (Q69_SER <= -1 )
replace Q69_FAC = . if (Q69_FAC <= -1 )
replace Q70MED = . if (Q70MED <= -1 )
replace Q71ADM = . if (Q71ADM <= -1 )
replace Q72DIS = . if (Q72DIS <= -1 )
replace Q73OTHR = . if (Q73OTHR <= -1 )
replace Q74_METH = . if (Q74_METH <= -1 )
replace Q74ATOT = . if (Q74ATOT <= -1 )
replace Q74AGIV = . if (Q74AGIV <= -1 )
replace Q74ANUM = . if (Q74ANUM <= -1 )
replace Q74APLC = . if (Q74APLC <= -1 )
replace Q74BTOT = . if (Q74BTOT <= -1 )
replace Q74BGIV = . if (Q74BGIV <= -1 )
replace Q74BNUM = . if (Q74BNUM <= -1 )
replace Q74BPLC = . if (Q74BPLC <= -1 )
replace Q75_HOME = . if (Q75_HOME <= -1 )
replace Q76_DIS = . if (Q76_DIS <= -1 )
replace Q79SUB = . if (Q79SUB <= -1 )
replace Q80_PLN = . if (Q80_PLN <= -1 )
replace Q81AFTR = . if (Q81AFTR <= -1 )
replace Q74A_YR = . if (Q74A_YR <= -1 )
replace Q74B_YR = . if (Q74B_YR <= -1 )
replace Q77_YR = . if (Q77_YR <= -1 )
replace Q78_YR = . if (Q78_YR <= -1 )
replace Q81A = . if (Q81A <= -1 )
replace Q81B = . if (Q81B <= -1 )
replace Q81C = . if (Q81C <= -1 )
replace Q81D = . if (Q81D <= -1 )
replace Q81E = . if (Q81E <= -1 )
replace Q81F = . if (Q81F <= -1 )
replace Q81G = . if (Q81G <= -1 )
replace Q81H = . if (Q81H <= -1 )
replace Q81I = . if (Q81I <= -1 )
replace Q81J = . if (Q81J <= -1 )
replace Q82AFTR = . if (Q82AFTR <= -1 )
replace Q83BILL = . if (Q83BILL <= -1 )
replace Q83A_DOL = . if (Q83A_DOL <= -1 )
replace Q83CODE = . if (Q83CODE <= -1 )
replace Q83PCNT = . if (Q83PCNT <= -1 )
replace Q83B = . if (Q83B <= -1 )
replace Q353CMNT = . if (Q353CMNT <= -1 )
replace Q33B1RCD = . if (Q33B1RCD <= -1 )
replace Q33B2RCD = . if (Q33B2RCD <= -1 )
replace Q33CODE = . if (Q33CODE <= -1 )
replace Q33RCODE = . if (Q33RCODE <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

